@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2012 Match Grun and the Claws Mail team
+ * Copyright (C) 2002-2024 the Claws Mail team and Match Grun
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 /*
@@ -31,7 +30,6 @@
 #endif
 
 #include <sys/stat.h>
-#include <dirent.h>
 #include <errno.h>
 #include <time.h>
 #include <string.h>
@@ -44,11 +42,6 @@
 #include "xmlprops.h"
 #include "file-utils.h"
 
-#ifdef MKDIR_TAKES_ONE_ARG
-#undef mkdir
-#define mkdir(a,b) mkdir(a)
-#endif
-
 #define DFL_DIR_CLAWS_OUT  "claws-mail-out"
 #define DFL_FILE_CLAWS_OUT "addressbook.html"
 
@@ -1043,7 +1036,7 @@ gboolean exporthtml_create_dir( ExportHtmlCtl *ctl ) {
 	gboolean retVal = FALSE;
 
 	ctl->rcCreate = 0;
-	if( mkdir( ctl->dirOutput, S_IRWXU ) == 0 ) {
+	if( g_mkdir( ctl->dirOutput, S_IRWXU ) == 0 ) {
 		retVal = TRUE;
 	}
 	else {
