@@ -1,5 +1,5 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2012 Colin Leroy <colin@colino.net> and 
  * the Claws Mail team
  *
@@ -178,7 +178,7 @@ static void bogofilter_create_widget_func(PrefsPage * _page,
 			_("Messages larger than this will not be checked"));
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(max_size_spinbtn), TRUE);
 
-	max_size_kb_label = gtk_label_new(_("KB"));
+	max_size_kb_label = gtk_label_new(_("KiB"));
 	gtk_widget_show(max_size_kb_label);
 	gtk_box_pack_start(GTK_BOX(hbox_max_size), max_size_kb_label, FALSE, FALSE, 0);
 
