@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2021 the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2022 the Claws Mail team
  * This file Copyright (C) 2006 Colin Leroy <colin@colino.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -178,9 +178,9 @@ static void pgpview_show_mime_part(TextView *textview, MimeInfo *partinfo)
 		if (!prefs_common_get_prefs()->work_offline) {
 			val = alertpanel(_("Key import"),
 				_("This key is not in your keyring. Do you want "
-				  "Claws Mail to try and import it?"),
-				  _("_No"), _("from keyserver"), _("from Web Key Directory"),
-				  ALERTFOCUS_SECOND);
+				  "Claws Mail to try to import it?"),
+				  NULL, _("_No"), NULL, _("from keyserver"),
+				  NULL, _("from Web Key Directory"), ALERTFOCUS_SECOND);
 			GTK_EVENTS_FLUSH();
 		}
 		if (val == G_ALERTDEFAULT) {
@@ -304,6 +304,7 @@ static void pgpview_show_mime_part(TextView *textview, MimeInfo *partinfo)
 
 		TEXTVIEW_INSERT(":\n\n");
 		TEXTVIEW_INSERT(_("   This key is in your keyring.\n"));
+		gpgme_key_unref(key);
 	}
 	gpgme_data_release(sigdata);
 	gpgme_release(ctx);
