@@ -32,9 +32,6 @@
 #  include <config.h>
 #endif
 
-/* this is needed for strptime() */
-#define _XOPEN_SOURCE /* glibc2 needs this */
-
 #include <time.h>
 #include <glib.h>
 //#include <locale.h>
