@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 2005-2023 the Claws Mail Team and Colin Leroy
+ * Copyright (C) 2005-2024 the Claws Mail Team and Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -257,8 +257,6 @@ static GtkWidget *date_format_create(GtkButton *button, void *data)
 
 	datefmt_list_view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(G_OBJECT(store));
-	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(datefmt_list_view),
-				     prefs_common.use_stripes_everywhere);
 	gtk_widget_show(datefmt_list_view);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow1), datefmt_list_view);
 
