@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2019 the Claws Mail team and Hiroyuki Yamamoto
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2022 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -314,7 +314,7 @@ static void summary_search_create(void)
 	g_signal_connect(G_OBJECT(bool_optmenu), "changed",
 			 G_CALLBACK(optmenu_changed), NULL);
 
-	clear_btn = gtkut_stock_button("edit-clear");
+	clear_btn = gtkut_stock_button("edit-clear", _("C_lear"));
 	gtk_widget_show(clear_btn);
 	gtk_box_pack_end(GTK_BOX(bool_hbox), clear_btn, FALSE, FALSE, 0);
 
@@ -482,17 +482,17 @@ static void summary_search_create(void)
 	gtk_box_pack_start(GTK_BOX(confirm_area), all_btn, TRUE, TRUE, 0);
 	gtk_widget_show(all_btn);
 
-	prev_btn = gtkut_stock_button("go-previous");
+	prev_btn = gtkut_stock_button("go-previous", _("_Previous"));
 	gtk_widget_set_can_default(prev_btn, TRUE);
 	gtk_box_pack_start(GTK_BOX(confirm_area), prev_btn, TRUE, TRUE, 0);
 	gtk_widget_show(prev_btn);
 
-	next_btn = gtkut_stock_button("go-next");
+	next_btn = gtkut_stock_button("go-next", _("_Next"));
 	gtk_widget_set_can_default(next_btn, TRUE);
 	gtk_box_pack_start(GTK_BOX(confirm_area), next_btn, TRUE, TRUE, 0);
 	gtk_widget_show(next_btn);
 
-	close_btn = gtk_button_new_with_mnemonic("_Close");
+	close_btn = gtkut_stock_button("window-close", _("_Close"));
 	gtk_widget_set_can_default(close_btn, TRUE);
 	gtk_box_pack_start(GTK_BOX(confirm_area), close_btn, TRUE, TRUE, 0);
 	gtk_widget_show(close_btn);
@@ -782,7 +782,8 @@ static void summary_search_execute(gboolean backward, gboolean search_all)
 			if (all_searched) {
 				alertpanel_full(_("Search failed"),
 						_("Search string not found."),
-				 		_("_Close"), NULL, NULL, ALERTFOCUS_FIRST,
+				 		"window-close", _("_Close"), NULL, NULL,
+						NULL, NULL, ALERTFOCUS_FIRST,
 						FALSE, NULL, ALERT_WARNING);
 				break;
 			}
@@ -793,7 +794,7 @@ static void summary_search_execute(gboolean backward, gboolean search_all)
 				str = _("End of list reached; continue from beginning?");
 
 			val = alertpanel(_("Search finished"), str,
-					 _("_No"), _("_Yes"), NULL,
+					 NULL, _("_No"), NULL, _("_Yes"), NULL, NULL,
 					 ALERTFOCUS_SECOND);
 			if (G_ALERTALTERNATE == val) {
 				if (backward) {
